/*-----------------------------------------------------------------------------
 * Copyright (c) 2008 Civic Computing Ltd.
 * All rights reserved.
 *
 * This file is part of Content Control.
 *
 * Content Control is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Content Control is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Content Control.  If not, see http://www.gnu.org/licenses/.
 *
 * Revision      $Rev: 2920 $
 * Modified by   $Author: keith $
 * Modified on   $Date: 2010-06-16 13:02:35 +0300 (Wed, 16 Jun 2010) $
 *
 * Changes: see subversion log.
 *-----------------------------------------------------------------------------
 */
package ccc.api.core;

import java.io.Serializable;
import java.util.Date;

import ccc.api.types.CommandType;
import ccc.api.types.Username;


/**
 * A summary of a log entry.
 *
 * @author Civic Computing Ltd.
 */
public final class Revision implements Serializable {
    private CommandType _command;
    private Username _actorUsername;
    private Date _happenedOn;
    private long _index;
    private String _comment;
    private boolean _isMajor;

    /**
     * Constructor.
     */
    public Revision() { super(); }

    /**
     * Constructor.
     *
     * @param command The action.
     * @param actorUsername The action's actor.
     * @param on The date of the action.
     * @param index The index of the action.
     * @param comment The comment of the action.
     * @param isMajorEdit Is the action a major edit.
     */
    public Revision(final CommandType  command,
                           final Username  actorUsername,
                           final Date    on,
                           final long    index,
                           final String comment,
                           final boolean isMajorEdit) {
        _command = command;
        _actorUsername = actorUsername;
        _happenedOn = new Date(on.getTime());
        _index = index;
        _comment = comment;
        _isMajor = isMajorEdit;
    }


    /**
     * Accessor.
     *
     * @return Returns the action.
     */
    @Deprecated // This method is due to be removed in 7.3.0
    public CommandType getCommand() {
        return _command;
    }


    /**
     * Accessor.
     *
     * @return Returns the actor.
     */
    public Username getActorUsername() {
        return _actorUsername;
    }


    /**
     * Accessor.
     *
     * @return Returns the happenedOn.
     */
    public Date getHappenedOn() {
        return new Date(_happenedOn.getTime());
    }


    /**
     * Accessor.
     *
     * @return Returns the index.
     */
    public long getIndex() {
        return _index;
    }


    /**
     * Accessor.
     *
     * @return Returns the comment.
     */
    public String getComment() {
        return _comment;
    }


    /**
     * Accessor.
     *
     * @return Returns the isMajor.
     */
    public boolean isMajor() {
        return _isMajor;
    }
}
