/*-----------------------------------------------------------------------------
 * Copyright (c) 2009 Civic Computing Ltd.
 * All rights reserved.
 *
 * This file is part of Content Control.
 *
 * Content Control is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Content Control is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Content Control.  If not, see http://www.gnu.org/licenses/.
 *
 * Revision      $Rev: 2841 $
 * Modified by   $Author: keith $
 * Modified on   $Date: 2010-05-27 20:22:22 +0300 (Thu, 27 May 2010) $
 *
 * Changes: see subversion log.
 *-----------------------------------------------------------------------------
 */
package ccc.api.exceptions;

import java.util.Collections;
import java.util.UUID;

import ccc.api.types.DBC;


/**
 * This exception indicates that a cycle was detected where a resource refers to
 * itself, either directly or indirectly.
 * <p>Examples would be an alias whose target points to itself or a folder that
 * contains itself.
 *
 * @author Civic Computing Ltd.
 */
public class CycleDetectedException
    extends
        InvalidException {


    /** Constructor. */
    public CycleDetectedException() { super(); }


    /**
     * Constructor.
     *
     * @param resource The resource for which a cycle was detected.
     */
    public CycleDetectedException(final UUID resource) {
        super(
            "Cycle detected for "
                + DBC.require().notNull(resource)
                + ".",
            Collections.singletonMap(RESOURCE, resource.toString()));
    }
}
