/*-----------------------------------------------------------------------------
 * Copyright © 2010 Civic Computing Ltd.
 * All rights reserved.
 *
 * This file is part of Content Control.
 *
 * Content Control is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Content Control is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Content Control.  If not, see http://www.gnu.org/licenses/.
 *
 * Revision      $Rev: 3042 $
 * Modified by   $Author: keith $
 * Modified on   $Date: 2010-08-17 19:50:42 +0300 (Tue, 17 Aug 2010) $
 *
 * Changes: see the subversion log.
 *-----------------------------------------------------------------------------
 */
package ccc.api.exceptions;

import java.util.Map;
import java.util.UUID;


/**
 * This request indicates that an API method was invoked with incorrect inputs.
 *
 * @author Civic Computing Ltd.
 */
public class InvalidException
    extends
        CCException {

    /** RESOURCE : String. */
    public static final String RESOURCE = "resource";
    /** RESOLUTION : String. */
    public static final String RESOLUTION = "resolution";


    /** Constructor. */
    public InvalidException() { super(); }


    /**
     * Constructor.
     *
     * @param message Description of the exception.
     */
    public InvalidException(final String message) {
        super(message, null);
    }


    /**
     * Constructor.
     *
     * @param message Description of the exception.
     * @param cause   The cause of this exception.
     */
    public InvalidException(final String message, final Throwable cause) {
        super(message, cause);
    }


    /**
     * Constructor.
     *
     * @param message Description of the exception.
     * @param params  Further details describing the exception.
     */
    public InvalidException(final String message,
                            final Map<String, String> params) {
        super(message, null, params);
    }


    /**
     * Accessor for the resource.
     *
     * @return The resource.
     */
    public UUID getResource() {
        return UUID.fromString(getParam(RESOURCE));
    }


    /**
     * Mutator for the resolution.
     *
     * @param resolution The resolution for this exception.
     */
    public void setResolution(final String resolution) {
        addParam(RESOLUTION, resolution);
    }
}
