/*-----------------------------------------------------------------------------
 * Copyright © 2010 Civic Computing Ltd.
 * All rights reserved.
 *
 * This file is part of Content Control.
 *
 * Content Control is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Content Control is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Content Control.  If not, see http://www.gnu.org/licenses/.
 *
 * Revision      $Rev: 3015 $
 * Modified by   $Author: keith $
 * Modified on   $Date: 2010-08-05 19:14:10 +0300 (Thu, 05 Aug 2010) $
 *
 * Changes: see the subversion log.
 *-----------------------------------------------------------------------------
 */
package ccc.api.types;

import java.util.Collection;



/**
 * A range of values.
 *
 * Modelled after Martin Fowler's Range pattern:
 * http://martinfowler.com/ap2/range.html
 * The NULL value is interpreted as meaning unlimited.
 *
 * @param <T> The type of range.
 *
 * @author Civic Computing Ltd.
 */
public final class CollectionRange{

	
    private final Class type;
    private final Collection values;
    private final int mode;


	public static final int MODE_OR = 0;
    public static final int MODE_AND = 1;

    /**
     * Constructor.
     *
     * @param clazz Class representing the type of the range.
     * @param values the values to look for
     */
    public CollectionRange(final Class clazz, Collection values) {
        this(clazz, values, MODE_OR);
    }
    
    /**
     * Constructor.
     *
     * @param clazz Class representing the type of the range.
     * @param values the values to look for
     */
    public CollectionRange(final Class clazz, Collection values, int mode) {
        type = DBC.require().notNull(clazz);
        this.values = values;
        this.mode = mode;
    }


    public Collection getValues() {
		return values;
	}

	public Class getType() {
		return type;
	}

    public int getMode() {
		return mode;
	}
}
