/*-----------------------------------------------------------------------------
 * Copyright © 2010 Civic Computing Ltd.
 * All rights reserved.
 *
 * This file is part of Content Control.
 *
 * Content Control is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Content Control is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Content Control.  If not, see http://www.gnu.org/licenses/.
 *
 * Revision      $Rev: 3571 $
 * Modified by   $Author: manosm $
 * Modified on   $Date: 2011-10-03 16:01:39 +0300 (Mon, 03 Oct 2011) $
 *
 * Changes: see the subversion log.
 *-----------------------------------------------------------------------------
 */
package ccc.plugins;

import static ccc.commons.Reflection.construct;

import java.io.InputStream;
import java.util.Properties;

import javax.mail.Session;

import org.apache.commons.configuration.Configuration;

import ccc.plugins.mail.Mailer;
import ccc.plugins.mail.javamail.JavaMailMailer;
import ccc.plugins.mail.javamail.PropertiesAuthenticator;
import ccc.plugins.multipart.MultipartFormData;
import ccc.plugins.scripting.TextProcessor;
import ccc.plugins.search.Index;
import ccc.plugins.search.Indexer;
import ccc.plugins.security.Sessions;


/**
 * Factory for plugins.
 *
 * @author Civic Computing Ltd.
 */
public class PluginFactory {
    
    public Mailer createMailer() {
        Session mail;
        final Properties config =
            ccc.commons.Resources.readIntoProps("mail.properties");
//        LOG.debug("Mail configuration: "+config);

        mail =
            Session.getInstance(config, new PropertiesAuthenticator(config));
        
        return new JavaMailMailer(mail);
    }


    public TextProcessor createTemplating() {
        return
            construct(
                TextProcessor.class,
                "ccc.plugins.scripting.velocity.VelocityProcessor");
    }


    public TextProcessor createScripting() {
        return
            construct(
                TextProcessor.class,
                "ccc.plugins.scripting.rhino.ScriptRunner");
    }


    public Index createIndex(Object... args) {
    	//Object[] args = {indexDir, lockDir, lockFactoryClass};
        return
            construct(
                Index.class,
                "ccc.plugins.search.lucene.SimpleLuceneFS",
                args);
    }


    public Indexer createIndexer(Object... args) {
    	//Object[] args = {indexDir, lockDir, lockFactoryClass};
        return
            construct(
                Indexer.class,
                "ccc.plugins.search.lucene.SimpleLuceneFS",
                args);
    }


    public Sessions createSessions() {
        return
            construct(
                Sessions.class,
                "ccc.plugins.security.jboss.JbossSession");
    }


    public MultipartFormData createFormData(final String charEncoding,
                                            final int contentLength,
                                            final String contentType,
                                            final InputStream inputStream) {

        final Class<?>[] types = new Class<?>[] {
            String.class,
            int.class,
            String.class,
            InputStream.class
        };

        final Object[] values = new Object[] {
            charEncoding,
            Integer.valueOf(contentLength),
            contentType,
            inputStream
        };

        return
            construct(
                MultipartFormData.class,
                "ccc.plugins.multipart.apache.MultipartForm",
                types,
                values);
    }
}
