/*-----------------------------------------------------------------------------
 * Copyright © 2010 Civic Computing Ltd.
 * All rights reserved.
 *
 * This file is part of Content Control.
 *
 * Content Control is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Content Control is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Content Control.  If not, see http://www.gnu.org/licenses/.
 *
 * Revision      $Rev: 3005 $
 * Modified by   $Author: keith $
 * Modified on   $Date: 2010-07-30 16:27:59 +0300 (Fri, 30 Jul 2010) $
 *
 * Changes: see the subversion log.
 *-----------------------------------------------------------------------------
 */

package ccc.plugins.s11n.json;

import ccc.plugins.s11n.Json;
import ccc.plugins.s11n.Serializer;


/**
 * Base class for serializers.
 *
 * @param <T> The type of object to serialize.
 *
 * @author Civic Computing Ltd.
 */
public abstract class AbstractSerializer<T>
    implements
        Serializer<T> {

    /** {@inheritDoc} */
    @Override
    public T read(final Json json) {
        if (null == json) { return null; }
        final T c = createObject();
        return c;
    }

    /**
     * Create a new instance of type T.
     *
     * @return The newly created instance of T.
     */
    protected abstract T createObject();

    /** {@inheritDoc} */
    @Override
    public Json write(final Json json, final T instance) {
        if (null == instance) { return null; }
        return json;
    }
}
